``pants.contrib.http``
**********************

.. automodule:: pants.contrib.http

Server
======

.. autoclass:: HTTPServer

.. autoclass:: HTTPConnection

.. autoclass:: HTTPRequest

Client
======

.. autoclass:: HTTPClient

.. autoclass:: ClientHelper

.. autoclass:: HTTPResponse
